import { ServiceBroker } from 'moleculer';
import type { CdmLogger } from '@cdm-logger/core';
import { BaseProxyService } from '@common-stack/store-mongo';
import { IAccountServiceContext, IIOnBoardingParams, IMoleculerServiceName, ITokenTypesEnum, IUpdateProfileInput, IUpdateUserAccountAliasesInput, IUserAccount, IUserAccountCreateRequest, IUserAccountLoginHistory, IUserAccountLoginHistorySystem, IUserAccountRemoveRequest, IUserAccountUpdateRequest, IUserAccountWhere, IUserAuth0UpdateFields, IUserProfile, IUsersToken, IUserToken } from 'common/lib/generated/generated-models.js';
import { IAccountService } from '../../interfaces';
export declare class AccountProxyService extends BaseProxyService<IUserAccount> implements IAccountService {
    protected logger?: CdmLogger.ILogger;
    protected topic: IMoleculerServiceName;
    constructor(broker: ServiceBroker, logger: CdmLogger.ILogger);
    getUserTokens(userId: string, tokenType: ITokenTypesEnum[]): Promise<IUserToken[]>;
    dispatchUserVerificationEmail(email: string, emailVerificationToken: IUserToken): Promise<void>;
    dispatchUserPasswordResetEmail(user: IUserAccount, token: string): Promise<void>;
    createDefaultAccount(user: any, context?: IAccountServiceContext): Promise<IUserAccount>;
    updateUserAccount(user: IUserProfile, userInfo: IUserAuth0UpdateFields): Promise<IUserAccount>;
    updateUserAccountAliases(input: IUpdateUserAccountAliasesInput): Promise<IUserAccount>;
    createAccount(account: IUserAccountCreateRequest): Promise<IUserAccount>;
    findAccountById(id: string): Promise<IUserAccount | Error>;
    findAccountByUser(id: string, context: IAccountServiceContext): Promise<IUserAccount | Error>;
    findAccountByEmail(email: string): Promise<IUserAccount | Error>;
    getUsers(where: IUserAccountWhere): Promise<IUserAccount[]>;
    updateAccount(account: IUserAccountUpdateRequest): Promise<IUserAccount>;
    deleteAccount(account: IUserAccountRemoveRequest): Promise<boolean>;
    accountOnBoarding(input: IIOnBoardingParams, context?: any): Promise<boolean>;
    deleteUserAccount(id: string): Promise<boolean>;
    getUserTokenDetails(userId: string, type: ITokenTypesEnum): Promise<IUserToken>;
    addUserToken(userId: string, token: IUserToken): Promise<boolean>;
    removeUserToken(userId: string, token: IUserToken): Promise<boolean>;
    getAllUserTokens(userIds: string[], tokenTypes: ITokenTypesEnum[]): Promise<IUsersToken[]>;
    getUserAccountByEmail(email: string): Promise<IUserAccount>;
    getAccountsLoginRecords(skip: number, limit: number): Promise<IUserAccountLoginHistory[]>;
    addAccountLoginHistoryRecord(args: {
        accountId: string;
        ipAddress: string;
        system: IUserAccountLoginHistorySystem;
    }): Promise<boolean>;
    updateUserProfile(account: IUpdateProfileInput, context?: IAccountServiceContext): Promise<boolean>;
}
